==> ts-pfsense_1.04-01.tar.gz: ts-pfsense/threatstop.conf.php <==
<?php
/**
 *
 * Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

$NDIG    = trim(shell_exec("which dig"));
# PATH sometimes, like in cron, does not contain /usr/local/bin/,
# and in 2.2+, dig is located there
if ( file_exists('/usr/local/bin/dig') ) {

	$NDIG='/usr/local/bin/dig';
}
if ( $NDIG === "" ) {

	echo "ERROR : cannot find DNS query utility (dig)";
}
$NDIG    = $NDIG . " +tcp +short";
$DNSLIST='192.124.129.42';
$BLOCKLIST='%blocklist%.threatstop.local';
$ALLOWLIST='%allowlist%.threatstop.local';

$PF_VERSION = trim(shell_exec("cat /etc/version | grep -o -E '^[0-9]+\.[0-9]+\.[0-9]+'"));
$PF_VERSION_PARTS = explode('.', $PF_VERSION);
$PF_VERSION_MAJOR = $PF_VERSION_PARTS[0];
$PF_VERSION_MINOR = $PF_VERSION_PARTS[1];

?>

==> ts-pfsense_1.05-02.tar.gz: ts-pfsense/threatstop.conf.php <==
<?php
/**
 *
 * Copyright(c) 2006-2018 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

// Select DNS client based on what's available; varies from version to version

$DIG_PATH    = trim(shell_exec("which dig"));
if ($DIG_PATH !== "") {
	$TSDIG = "dig";
	$NDIG = $DIG_PATH;
} else if (file_exists('/usr/local/bin/dig') ) {
	# PATH sometimes (e.g. cron jobs) does not contain /usr/local/bin/,
	# in 2.2+, dig is located there
	$TSDIG='dig';
	$NDIG = "/usr/local/bin/dig";
	} else {
		$DRILL_PATH  = trim(shell_exec("which drill"));
		if ($DRILL_PATH !== "") {
			$TSDIG = "drill";
			$NDIG = $DRILL_PATH;
		}
}

if ( $TSDIG === "" ) {
	echo "ERROR : cannot find DNS query utility (dig)";
	echo "See https://docs.threatstop.com/pfsense2.html";
}

// echo "DNS SETTINGS [$NDIG][$TSDIG]\n";

$DNSLIST='192.124.129.42';

$BLOCKLIST='%blocklist%';
$ALLOWLIST='%allowlist%';
$TDID='%tdid%';

$PF_VERSION = trim(shell_exec("cat /etc/version | grep -o -E '^[0-9]+\.[0-9]+\.[0-9]+'"));
$PF_VERSION_PARTS = explode('.', $PF_VERSION);
$PF_VERSION_MAJOR = $PF_VERSION_PARTS[0];
$PF_VERSION_MINOR = $PF_VERSION_PARTS[1];

?>
